==> jc-1.4.0.tar.gz: soot/javaToJimple/LocalClassChecker.h <==
// public class soot.javaToJimple.LocalClassChecker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 1eb12b30f1701cfb soot_javaToJimple_LocalClassChecker

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_LocalClassChecker_H_
#define _JC_soot_javaToJimple_LocalClassChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_LocalClassChecker$sub_refs	_jc_soot_javaToJimple_LocalClassChecker$sub_refs;
typedef struct _jc_soot_javaToJimple_LocalClassChecker$sub_nonrefs	_jc_soot_javaToJimple_LocalClassChecker$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_LocalClassChecker$refs	_jc_soot_javaToJimple_LocalClassChecker$refs;
typedef struct _jc_soot_javaToJimple_LocalClassChecker$nonrefs	_jc_soot_javaToJimple_LocalClassChecker$nonrefs;
typedef struct _jc_soot_javaToJimple_LocalClassChecker$object	_jc_soot_javaToJimple_LocalClassChecker$object;

typedef const struct _jc_soot_javaToJimple_LocalClassChecker$vmethods	_jc_soot_javaToJimple_LocalClassChecker$vmethods;
typedef const struct _jc_soot_javaToJimple_LocalClassChecker$vtable	_jc_soot_javaToJimple_LocalClassChecker$vtable;
typedef const struct _jc_soot_javaToJimple_LocalClassChecker$vtype	_jc_soot_javaToJimple_LocalClassChecker$vtype;

// Constructors
extern void _jc_soot_javaToJimple_LocalClassChecker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_LocalClassChecker$object *);

// Virtual methods
extern struct _jc_java_util_HashMap$object *_jc_soot_javaToJimple_LocalClassChecker$method$getClassMap$1f32dfe48f3df723(_jc_env *, struct _jc_soot_javaToJimple_LocalClassChecker$object *);
extern struct _jc_java_util_HashMap$object *_jc_soot_javaToJimple_LocalClassChecker$method$getMap$f4cb77aab22032d5(_jc_env *, struct _jc_soot_javaToJimple_LocalClassChecker$object *);
extern struct _jc_object *_jc_soot_javaToJimple_LocalClassChecker$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_soot_javaToJimple_LocalClassChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_LocalClassChecker$method_info$getClassMap$1f32dfe48f3df723;
extern _jc_method _jc_soot_javaToJimple_LocalClassChecker$method_info$getMap$f4cb77aab22032d5;
extern _jc_method _jc_soot_javaToJimple_LocalClassChecker$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_soot_javaToJimple_LocalClassChecker$vmethods {
	struct _jc_java_util_HashMap$object	*(*getClassMap$1f32dfe48f3df723)(_jc_env *, struct _jc_soot_javaToJimple_LocalClassChecker$object *);
	struct _jc_java_util_HashMap$object	*(*getMap$f4cb77aab22032d5)(_jc_env *, struct _jc_soot_javaToJimple_LocalClassChecker$object *);
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_soot_javaToJimple_LocalClassChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
};

// Vtable
struct _jc_soot_javaToJimple_LocalClassChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_LocalClassChecker$vmethods	soot_javaToJimple_LocalClassChecker;
};

// Vtype
struct _jc_soot_javaToJimple_LocalClassChecker$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_LocalClassChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_LocalClassChecker$sub_refs {
	struct _jc_java_util_HashMap$object	*map;
	struct _jc_java_util_HashMap$object	*classMap;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_LocalClassChecker$refs {
    _jc_soot_javaToJimple_LocalClassChecker$sub_refs	soot_javaToJimple_LocalClassChecker;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_LocalClassChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_LocalClassChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_LocalClassChecker$sub_nonrefs	soot_javaToJimple_LocalClassChecker;
};

// Object instance structure
struct _jc_soot_javaToJimple_LocalClassChecker$object {
	_jc_soot_javaToJimple_LocalClassChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_LocalClassChecker$vtype	*vtype;
	_jc_soot_javaToJimple_LocalClassChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_LocalClassChecker$vtype _jc_soot_javaToJimple_LocalClassChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_LocalClassChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_LocalClassChecker$class_object;

#endif	/* _JC_soot_javaToJimple_LocalClassChecker_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/LocalClassChecker.h <==
// public class soot.javaToJimple.LocalClassChecker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 1eb12b30f1701cfb soot_javaToJimple_LocalClassChecker

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_LocalClassChecker_H_
#define _JC_soot_javaToJimple_LocalClassChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_LocalClassChecker$sub_refs	_jc_soot_javaToJimple_LocalClassChecker$sub_refs;
typedef struct _jc_soot_javaToJimple_LocalClassChecker$sub_nonrefs	_jc_soot_javaToJimple_LocalClassChecker$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_LocalClassChecker$refs	_jc_soot_javaToJimple_LocalClassChecker$refs;
typedef struct _jc_soot_javaToJimple_LocalClassChecker$nonrefs	_jc_soot_javaToJimple_LocalClassChecker$nonrefs;
typedef struct _jc_soot_javaToJimple_LocalClassChecker$object	_jc_soot_javaToJimple_LocalClassChecker$object;

typedef const struct _jc_soot_javaToJimple_LocalClassChecker$vmethods	_jc_soot_javaToJimple_LocalClassChecker$vmethods;
typedef const struct _jc_soot_javaToJimple_LocalClassChecker$vtable	_jc_soot_javaToJimple_LocalClassChecker$vtable;
typedef const struct _jc_soot_javaToJimple_LocalClassChecker$vtype	_jc_soot_javaToJimple_LocalClassChecker$vtype;

// Constructors
extern void _jc_soot_javaToJimple_LocalClassChecker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_LocalClassChecker$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_HashMap$object *_jc_soot_javaToJimple_LocalClassChecker$method$getClassMap$1f32dfe48f3df723(_jc_env *, struct _jc_soot_javaToJimple_LocalClassChecker$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_HashMap$object *_jc_soot_javaToJimple_LocalClassChecker$method$getMap$f4cb77aab22032d5(_jc_env *, struct _jc_soot_javaToJimple_LocalClassChecker$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_javaToJimple_LocalClassChecker$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_soot_javaToJimple_LocalClassChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_LocalClassChecker$method_info$getClassMap$1f32dfe48f3df723;
extern _jc_method _jc_soot_javaToJimple_LocalClassChecker$method_info$getMap$f4cb77aab22032d5;
extern _jc_method _jc_soot_javaToJimple_LocalClassChecker$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_soot_javaToJimple_LocalClassChecker$vmethods {
	struct _jc_java_util_HashMap$object	*(*getClassMap$1f32dfe48f3df723)(_jc_env *, struct _jc_soot_javaToJimple_LocalClassChecker$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_HashMap$object	*(*getMap$f4cb77aab22032d5)(_jc_env *, struct _jc_soot_javaToJimple_LocalClassChecker$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_soot_javaToJimple_LocalClassChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_LocalClassChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_LocalClassChecker$vmethods	soot_javaToJimple_LocalClassChecker;
};

// Vtype
struct _jc_soot_javaToJimple_LocalClassChecker$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_LocalClassChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_LocalClassChecker$sub_refs {
	struct _jc_java_util_HashMap$object	*map;
	struct _jc_java_util_HashMap$object	*classMap;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_LocalClassChecker$refs {
    _jc_soot_javaToJimple_LocalClassChecker$sub_refs	soot_javaToJimple_LocalClassChecker;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_LocalClassChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_LocalClassChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_LocalClassChecker$sub_nonrefs	soot_javaToJimple_LocalClassChecker;
};

// Object instance structure
struct _jc_soot_javaToJimple_LocalClassChecker$object {
	_jc_soot_javaToJimple_LocalClassChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_LocalClassChecker$vtype	*vtype;
	_jc_soot_javaToJimple_LocalClassChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_LocalClassChecker$vtype _jc_soot_javaToJimple_LocalClassChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_LocalClassChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_LocalClassChecker$class_object;

#endif	/* _JC_soot_javaToJimple_LocalClassChecker_H_ */
